Struct quantette::AboveMaxLen
source · pub struct AboveMaxLen<T>(pub T);Expand description
An error type for when the length of an input (e.g., Vec or slice)
is above the maximum supported value.
The inner value is the maximum supported value.
Tuple Fields
0: TTrait Implementations
sourceimpl<T: Clone> Clone for AboveMaxLen<T>
impl<T: Clone> Clone for AboveMaxLen<T>
sourcefn clone(&self) -> AboveMaxLen<T>
fn clone(&self) -> AboveMaxLen<T>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<T: Debug> Debug for AboveMaxLen<T>
impl<T: Debug> Debug for AboveMaxLen<T>
sourceimpl<T: Display> Display for AboveMaxLen<T>
impl<T: Display> Display for AboveMaxLen<T>
sourceimpl<T: Debug + Display> Error for AboveMaxLen<T>
impl<T: Debug + Display> Error for AboveMaxLen<T>
1.30.0 · sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
sourceimpl<T: Ord> Ord for AboveMaxLen<T>
impl<T: Ord> Ord for AboveMaxLen<T>
sourcefn cmp(&self, other: &AboveMaxLen<T>) -> Ordering
fn cmp(&self, other: &AboveMaxLen<T>) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl<T: PartialEq> PartialEq for AboveMaxLen<T>
impl<T: PartialEq> PartialEq for AboveMaxLen<T>
sourcefn eq(&self, other: &AboveMaxLen<T>) -> bool
fn eq(&self, other: &AboveMaxLen<T>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl<T: PartialOrd> PartialOrd for AboveMaxLen<T>
impl<T: PartialOrd> PartialOrd for AboveMaxLen<T>
sourcefn partial_cmp(&self, other: &AboveMaxLen<T>) -> Option<Ordering>
fn partial_cmp(&self, other: &AboveMaxLen<T>) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl<T: Copy> Copy for AboveMaxLen<T>
impl<T: Eq> Eq for AboveMaxLen<T>
impl<T> StructuralEq for AboveMaxLen<T>
impl<T> StructuralPartialEq for AboveMaxLen<T>