Struct quantette::KmeansOptions
source · pub struct KmeansOptions<Color> { /* private fields */ }Expand description
A builder struct to specify the parameters for k-means.
Examples
let options = KmeansOptions::new()
.sampling_factor(0.25)
.seed(42);Implementations
sourceimpl<Color> KmeansOptions<Color>
impl<Color> KmeansOptions<Color>
sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new KmeansOptions with default values.
sourcepub fn sampling_factor(self, sampling_factor: f32) -> Self
pub fn sampling_factor(self, sampling_factor: f32) -> Self
Sets the sampling factor which controls what percentage of the image/unique colors to sample.
The default sampling factor is 0.5, that is, to sample half of the input.
Negative or NAN sampling factors will cause k-means to not be run.
sourcepub fn initial_centroids(self, centroids: Centroids<Color>) -> Self
pub fn initial_centroids(self, centroids: Centroids<Color>) -> Self
Sets the initial colors/centroids for the k-means algorithm.
By default, these are computed through Wu’s quantiztion algorithm
(see the wu module).
sourcepub fn seed(self, seed: u64) -> Self
pub fn seed(self, seed: u64) -> Self
Sets the seed value for the random number generator.
The default seed is 0.
sourcepub fn batch_size(self, batch_size: u32) -> Self
pub fn batch_size(self, batch_size: u32) -> Self
Sets the batch size for the parallel implementation of the k-means quantizer (minibatch k-means).
Larger batch sizes are faster with dimishing returns. Smaller batch sizes are more accurate but slower to run. The batch is divided evenly among the number of threads.
The default batch size is 4096.