pub struct QuantizeOutput<Color> {
    pub palette: Vec<Color>,
    pub counts: Vec<u32>,
    pub indices: Vec<u8>,
}
The output struct returned by quantization functions.

It contains the color palette for the image, alongside counts which has the number of pixels/samples assigned to each palette color. Additionally, indices will contain a index into palette for each pixel, but only if the quantization function computes an indexed palette (e.g., wu::indexed_palette). Otherwise, indices will be empty (e.g., wu::palette).

Note that all fields will be empty if a PaletteSize of 0 was provided to the quantization function.

Fields

palette: Vec<Color>

The computed color palette that is representative of the colors in the image.

The colors in the palette are not guaranteed to be unique.

counts: Vec<u32>

The number of pixels or samples that were assigned to each color in palette.

Each count is not guaranteed to be non-zero.

indices: Vec<u8>

The remapped image, where each pixel is replaced with an index into palette.

This will be empty if the quantization function does not compute an indexed palette.